@@ -6,7 +6,7 @@ import gymnasium
 import matplotlib.pyplot as plt
 import numpy as np
 
-import PyFlyt
+import PyFlyt.gym_envs
 
 env = gymnasium.make(
     "PyFlyt/SimpleWaypointEnv-v0",
